@@ -1,4 +1,4 @@
-var assetUrl = __admin_media_prefix__.substring(0, __admin_media_prefix__.lastIndexOf('/'))
+var assetUrl = __admin_media_prefix__.replace('/admin/', '')
 
 if( ! jQuery.widget) $.getScript(assetUrl + '/jquery.ui.widget.js')
 if( ! $.ajaxTransport) $.getScript(assetUrl + '/jquery.iframe-transport.js')
