@@ -23,9 +23,6 @@ class S3DirectEditor(widgets.TextInput):
 
     class Media:
         js = (
-            's3direct/js/jquery.ui.widget.js',
-            's3direct/js/jquery.iframe-transport.js',
-            's3direct/js/jquery.fileupload.js',
             's3direct/js/s3direct.js',
         )
         css = {
